Index: chrome/browser/nacl_host/nacl_process_host.h |
=================================================================== |
--- chrome/browser/nacl_host/nacl_process_host.h (revision 69057) |
+++ chrome/browser/nacl_host/nacl_process_host.h (working copy) |
@@ -13,7 +13,7 @@ |
#include "chrome/common/nacl_types.h" |
#include "native_client/src/shared/imc/nacl_imc.h" |
-class ResourceMessageFilter; |
+class RenderMessageFilter; |
// Represents the browser side of the browser <--> NaCl communication |
// channel. There will be one NaClProcessHost per NaCl process |
@@ -28,7 +28,7 @@ |
~NaClProcessHost(); |
// Initialize the new NaCl process, returning true on success. |
- bool Launch(ResourceMessageFilter* resource_message_filter, |
+ bool Launch(RenderMessageFilter* render_message_filter, |
int socket_count, |
IPC::Message* reply_msg); |
@@ -62,9 +62,9 @@ |
private: |
ResourceDispatcherHost* resource_dispatcher_host_; |
// The ResourceMessageFilter that requested this NaCl process. We use this |
// for sending the reply once the process has started. |
- scoped_refptr<ResourceMessageFilter> resource_message_filter_; |
+ scoped_refptr<RenderMessageFilter> render_message_filter_; |
// The reply message to send. |
IPC::Message* reply_msg_; |
@@ -62,9 +62,9 @@ |
private: |
ResourceDispatcherHost* resource_dispatcher_host_; |
- // The ResourceMessageFilter that requested this NaCl process. We use this |
+ // The RenderMessageFilter that requested this NaCl process. We use this |
// for sending the reply once the process has started. |